module.exports = defineTest({
	description: 'removes unknown getter access without side effect',
	options: { external: ['external'] }
});
